@@ -160,6 +160,16 @@
  *     count: true
  * });
  * 
+ *
+ * Pintarest Button
+ * http://pinterest.com/about/goodies/
+ *
+ * $('#pinterest').socialbutton('pinterest', {
+ *     button: 'horizontal', // or 'vertical', 'none'
+ *     url: 'http://itra.jp',
+ *     media: 'http://itra.jp/image.jpg',
+ *     description: 'This is an image.',
+ * });
  */
 (function($) {
 
@@ -274,7 +284,13 @@ $.fn.socialbutton = function(service, options) {
 			parsetags: '', // none(onload), explicit
 			callback: '',
 			count: true // true, false
-		}
+		},
+		pinterest: {
+			button: 'horizontal', // horizontal, vertical, none
+			url: '',
+			media: '',
+			description: ''
+		},
 	};
 
 	var max_index = this.size() - 1;
@@ -322,6 +338,10 @@ $.fn.socialbutton = function(service, options) {
 				socialbutton_google_plusone(this, options, defaults.google_plusone, index, max_index);
 				break;
 
+			case 'pinterest':
+				socialbutton_pinterest(this, options, defaults.pinterest, index, max_index);
+				break;
+
 			default:
 				break;
 		}
@@ -740,6 +760,32 @@ function socialbutton_google_plusone(target, options, defaults, index, max_index
 	}
 }
 
+function socialbutton_pinterest(target, options, defaults, index, max_index)
+{
+	var url = options.url || defaults.url;
+	var button = options.button || defaults.button;
+	var media = options.media != undefined ? options.media : defaults.media;
+	var description = options.description != undefined ? options.description : defaults.description;
+
+	url = url_encode_rfc3986(decodeURIComponent(url));
+	media = url_encode_rfc3986(decodeURIComponent(media));
+	description = decodeURIComponent(description);
+
+	var params = merge_parameters({
+		'url': url,
+		'media': media,
+		'description': description
+	});
+
+	var tag = '<a href="http://pinterest.com/pin/create/button/?' + params + '" class="pin-it-button" count-layout="' + button +'"><img border="0" src="//assets.pinterest.com/images/PinExt.png" title="Pin It" /></a>'
+
+	$(target).html(tag);
+
+	if (index == max_index) {
+		$('body').append('<script type="text/javascript" src="//assets.pinterest.com/js/pinit.js"></script>');
+	}
+}
+
 function merge_attributes(attr)
 {
 	var merged = '';
